__init__ — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# __init__

FermiHandler.__init__(code: str, dirname: str = '', fermi: float | None = None, repair: bool = False, apply_symmetry: bool = True)

  This class handles the plotting of the fermi surface. Initialize by specifying the code and directory name where the data is stored. Then call one of the plotting methods provided.

  Parameters:

    - code (str) – The code name

    - dirname (str, optional) – the directory name where the calculation is, by default “”

    - fermi (float, optional) – The fermi energy. This will overide the default fermi value used found in the given directory, by default None

    - repair (bool, optional) – Boolean to repair the PROCAR file, by default False

    - apply_symmetry (bool, optional) – Boolean to apply symmetry to the fermi sruface. This is used when only symmetry reduced kpoints used in the calculation, by default True